'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _classnames = require('../_utils/classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

exports['default'] = {
    props: {
        dot: Boolean,
        type: String,
        info: [Number, String],
        color: String,
        title: String,
        isActive: Boolean,
        ellipsis: Boolean,
        disabled: Boolean,
        scrollable: Boolean,
        activeColor: String,
        inactiveColor: String,
        swipeThreshold: [Number, String]
    },

    computed: {
        style: function style() {
            var style = {};
            var color = this.color,
                isActive = this.isActive;

            var isCard = this.type === 'card';

            // card theme color
            if (color && isCard) {
                style.borderColor = color;

                if (!this.disabled) {
                    if (isActive) {
                        style.backgroundColor = color;
                    } else {
                        style.color = color;
                    }
                }
            }

            var titleColor = isActive ? this.activeColor : this.inactiveColor;
            if (titleColor) {
                style.color = titleColor;
            }

            if (this.scrollable && this.ellipsis) {
                style.flexBasis = 88 / this.swipeThreshold + '%';
            }

            return style;
        }
    },

    methods: {
        onClick: function onClick() {
            this.$emit('click');
        }
    },

    render: function render() {
        var h = arguments[0];

        return h(
            'div',
            {
                attrs: {
                    role: 'tab',
                    'aria-selected': this.isActive
                },
                'class': (0, _classnames2['default'])({
                    'sn-tab': true,
                    'sn-tab-active': this.isActive,
                    disabled: this.disabled,
                    complete: !this.ellipsis,
                    'sn-ellipsis': this.ellipsis
                }),
                style: this.style,
                on: {
                    'click': this.onClick
                }
            },
            [h(
                'span',
                { 'class': 'sn-tab-text' },
                [this.$slots['default'] || this.title, this.info]
            )]
        );
    }
};
module.exports = exports.default;